"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const multer = require('multer');
const setting_config_1 = require("../config/setting.config");
const MIME_TYPE_MAPs = {
    'text/csv': 'csv',
    'audio/3gpp': '3ga',
    'video/3gpp': '3gp',
    'text/plain': 'txt',
    'audio/amr': 'amr',
    'video/x-msvideo': 'avi',
    'image/bmp': 'bmp',
    'application/x-bzip2': 'bz2',
    'application/calendar': 'cal',
    'text/css': 'css',
    'image/dib': 'dib',
    'audio/flac': 'flac',
    'video/x-flv': 'flv',
    'image/gif': 'gif',
    'application/x-gzip': 'gz',
    'image/x-icon': 'ico',
    'image/jpeg': 'jpeg',
    'image/jpg': 'jpg',
    'application/javascript': 'js',
    'application/json': 'json',
    'audio/mpeg': 'm1a',
    'video/m1v': 'm1v',
    'audio/m2a': 'm2a',
    'audio/x-m4a': 'm4a',
    'audio/m4b': 'm4b',
    'audio/x-mp3': 'mp3',
    'video/mp4': 'mp4',
    'audio/x-ms-wma': 'mpa',
    'video/mpeg': 'mpeg',
    'video/mpg': 'mpg',
    'application/pdf': 'pdf',
    'image/pjpeg': 'pjpeg',
    'image/png': 'png',
    'video/quicktime': 'qt',
    'text/rtf': 'rtf',
    'audio/x-wav': 'wav',
    'video/webm': 'webm',
    'image/webp': 'webp',
    'video/x-ms-wmv': 'wmv',
    'application/xml': 'xml',
    'application/zip': 'zip'
};
const storage = multer.diskStorage({
    destination: (req, fileToUpload, cb) => {
        let usernotesdir = new setting_config_1.UploadDirectory();
        const isValid = MIME_TYPE_MAPs[fileToUpload.mimetype];
        let error = "";
        if (!isValid) {
            error = new Error("Invalid file type");
        }
        cb(error, usernotesdir.SAVENOTES);
    },
    filename: (req, fileToUpload, cb) => {
        let file_path = fileToUpload.originalname;
        let extension = file_path.split('.').pop();
        let randomName = Math.random().toString(36).substring(2, 12);
        const filenm = fileToUpload.originalname;
        const flName = Date.now() + '-' + filenm.replace(filenm, randomName);
        const fileName = flName + '.' + extension;
        const ext = MIME_TYPE_MAPs[fileToUpload.mimetype];
        cb(null, fileName);
    }
});
module.exports = [multer({ storage: storage }).array('ATTACHMENTS')];
